pub enum ServiceOutcome {
Completed,
NoShow,
LateCancelled,
NeedsFollowUp,
}Expand description
Service outcome recorded for grooming history, estimates, and rebooking prompts.
Variants
Completed
Staff can see the completed grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
NoShow
Staff can see the no show grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
LateCancelled
Staff can see the late cancelled grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
NeedsFollowUp
Staff can see the needs follow up grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.